"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFileNameFilter = void 0;
const node_path_1 = __importDefault(require("node:path"));
const glob_to_regexp_1 = require("../string-util/glob-to-regexp");
function createFileNameFilter({ specs, projectName, _forceWin32 = false, }) {
    const path = _forceWin32 ? node_path_1.default.win32 : node_path_1.default;
    const testers = (specs !== null && specs !== void 0 ? specs : []).map(pattern => {
        if (pattern.includes('*') || pattern.includes('?')) {
            const regexp = (0, glob_to_regexp_1.globToRegExp)(pattern);
            return (normalized) => regexp.test(normalized);
        }
        else {
            const dirOrFileName = pattern[pattern.length - 1] === '/' ? pattern.slice(0, pattern.length - 1) : pattern;
            return (normalized) => normalized === dirOrFileName || normalized.startsWith(dirOrFileName + '/');
        }
    });
    const projectRootDirName = path.dirname(projectName);
    const match = (fileName) => {
        const normalized = path.relative(projectRootDirName, fileName).replace(/\\/g, '/');
        return testers.some(tester => tester(normalized));
    };
    return match;
}
exports.createFileNameFilter = createFileNameFilter;
//# sourceMappingURL=file-name-filter.js.map